starcluster.threadpool.ThreadPool

Package starcluster :: Module threadpool :: Class ThreadPool |
[hide private]
[frames] | no frames]

# Class ThreadPool

source code

Instance Methods | [hide private]
__init__(self, size=1, maxjobs=0, worker_factory=<function _worker_factory at 0x1829668>, disable_threads=False) | source code
simple_job(self, method, args=`[``]`, kwargs=`{``}`, jobid=None, results_queue=None) | source code
get_results(self) | source code
map(self, fn, *seq) Perform a map operation distributed among the workers. | source code
store_exception(self, e) | source code
shutdown(self) Retire the workers. | source code
wait(self, numtasks=None, return_results=True) DEPRECATED: Use join() instead. | source code
__del__(self) | source code
Inherited from `workerpool.pools.WorkerPool`: `grow`, `shrink`, `size` Inherited from `Queue.Queue`: `empty`, `full`, `get`, `get_nowait`, `join`, `put`, `put_nowait`, `qsize`, `task_done` Inherited from `Queue.Queue` (private): `_get`, `_init`, `_put`, `_qsize`

Properties | [hide private]
| progress_bar

Method Details | [hide private]

### __init__(self, size=1, maxjobs=0, worker_factory=<function _worker_factory at 0x1829668>, disable_threads=False) (Constructor) | source code
Overrides: Queue.Queue.__init__

### map(self, fn, *seq) | source code
Perform a map operation distributed among the workers. Will block until done. Overrides: workerpool.pools.WorkerPool.map (inherited documentation)

### shutdown(self) | source code
Retire the workers. Overrides: workerpool.pools.WorkerPool.shutdown (inherited documentation)

### wait(self, numtasks=None, return_results=True) | source code
DEPRECATED: Use join() instead. Overrides: workerpool.pools.WorkerPool.wait (inherited documentation)

Property Details | [hide private]

### progress_bar Get Method: unreachable.progress_bar(self)